==> skrooge_0.6.0.orig.tar.gz: skrooge-0.6.0/tests/suite_squish/tst_create_operation/test.py <==
def main():
    source(findFile("scripts", "skrooge_functions.py"))
    initSimple()
    
    waitForObject(":Untitled - skrooge_KTabBar")
    type(":Untitled - skrooge_KTabBar", "<Ctrl+2>")
    waitForObject(":kAccountCreatorBank_KLineEdit")
    mouseClick(":kAccountCreatorBank_KLineEdit", 21, 15, 0, Qt.LeftButton)
    waitForObject(":kAccountCreatorBank_KLineEdit")
    type(":kAccountCreatorBank_KLineEdit", "A")
    waitForObject(":kAccountCreatorBank_KLineEdit")
    type(":kAccountCreatorBank_KLineEdit", "<Tab>")
    waitForObject(":kAccountCreatorAccount_KLineEdit_2")
    type(":kAccountCreatorAccount_KLineEdit_2", "A")
    waitForObject(":kAccountCreatorAccount_KLineEdit_2")
    type(":kAccountCreatorAccount_KLineEdit_2", "<Ctrl+Return>")
    waitForObject(":kAccountCreatorAccount_KLineEdit_2")
    type(":kAccountCreatorAccount_KLineEdit_2", "<Shift+Return>")
    waitForObject(":kAccountCreatorAccount_KLineEdit_2")
    type(":kAccountCreatorAccount_KLineEdit_2", "<Ctrl+3>")
    waitForObject(":kAmountEdit_SKGCalculatorEdit_3")
    mouseClick(":kAmountEdit_SKGCalculatorEdit_3", 44, 8, 0, Qt.LeftButton)
    waitForObject(":kAmountEdit_SKGCalculatorEdit_3")
    type(":kAmountEdit_SKGCalculatorEdit_3", "<1>")
    waitForObject(":kAmountEdit_SKGCalculatorEdit_3")
    type(":kAmountEdit_SKGCalculatorEdit_3", "<0>")
    waitForObject(":kPayeeEdit_SKGComboBox")
    mouseClick(":kPayeeEdit_SKGComboBox", 62, 5, 0, Qt.LeftButton)
    waitForObject(":kPayeeEdit_SKGComboBox")
    type(":kPayeeEdit_SKGComboBox", "p")
    waitForObject(":kPayeeEdit_SKGComboBox")
    type(":kPayeeEdit_SKGComboBox", "<Tab>")
    waitForObject(":kTypeEdit_SKGComboBox")
    type(":kTypeEdit_SKGComboBox", "m")
    waitForObject(":kTypeEdit_SKGComboBox")
    type(":kTypeEdit_SKGComboBox", "<Tab>")
    waitForObject(":Skrooge operation plugin.kNumberEdit_SKGLineEdit")
    type(":Skrooge operation plugin.kNumberEdit_SKGLineEdit", "<Tab>")
    waitForObject(":kCategoryEdit_SKGComboBox_2")
    type(":kCategoryEdit_SKGComboBox_2", "c")
    waitForObject(":kCategoryEdit_SKGComboBox_2")
    type(":kCategoryEdit_SKGComboBox_2", "<Tab>")
    waitForObject(":kCategoryEdit_SKGComboBox_2")
    type(":kCategoryEdit_SKGComboBox_2", "<Tab>")
    waitForObject(":kCategoryEdit_SKGComboBox_2")
    type(":kCategoryEdit_SKGComboBox_2", "<Esc>")
    waitForObject(":kCategoryEdit_SKGComboBox_2")
    type(":kCategoryEdit_SKGComboBox_2", "<Tab>")
    waitForObject(":kCommentEdit_SKGComboBox")
    type(":kCommentEdit_SKGComboBox", "c")
    waitForObject(":kCommentEdit_SKGComboBox")
    type(":kCommentEdit_SKGComboBox", "<Tab>")
    waitForObject(":kTrackerEdit_SKGComboBox")
    type(":kTrackerEdit_SKGComboBox", "t")
    waitForObject(":kAmountEdit_SKGCalculatorEdit_3")
    mouseDrag(":kAmountEdit_SKGCalculatorEdit_3", 34, 10, 72, 0, 1, Qt.LeftButton)
    waitForObject(":kAmountEdit_SKGCalculatorEdit_3")
    type(":kAmountEdit_SKGCalculatorEdit_3", "<2>")
    waitForObject(":kAmountEdit_SKGCalculatorEdit_3")
    type(":kAmountEdit_SKGCalculatorEdit_3", "<0>")
    waitForObject(":kAmountEdit_SKGCalculatorEdit_3")
    type(":kAmountEdit_SKGCalculatorEdit_3", "<Shift+Return>")
    waitForObject(":kReconciliatorFrame.Templates_QToolButton")
    clickButton(":kReconciliatorFrame.Templates_QToolButton")
    waitForObject(":kReconciliatorFrame.Operations_QToolButton")
    clickButton(":kReconciliatorFrame.Operations_QToolButton")
    waitForObject(":kReconciliatorFrame.kReconciliatorButton_QToolButton")
    clickButton(":kReconciliatorFrame.kReconciliatorButton_QToolButton")
    waitForObject(":kReconciliatorFrame.kReconciliatorButton_QToolButton")
    clickButton(":kReconciliatorFrame.kReconciliatorButton_QToolButton")
    waitForObject(":Skrooge operation plugin.kOperationView_SKGTableView")
    mouseClick(":Skrooge operation plugin.kOperationView_SKGTableView", 1073, 556, 0, Qt.LeftButton)
    waitForObject(":Skrooge operation plugin.kOperationView_SKGTableView")
    type(":Skrooge operation plugin.kOperationView_SKGTableView", "<Ctrl+A>")
    waitForObject(":kReconciliatorFrame.kReconciliatorButton_QToolButton")
    clickButton(":kReconciliatorFrame.kReconciliatorButton_QToolButton")
    waitForObject(":Skrooge operation plugin.kOperationView_SKGTableView")
    mouseClick(":Skrooge operation plugin.kOperationView_SKGTableView", 228, 608, 0, Qt.LeftButton)
    waitForObject(":Skrooge operation plugin.Split_QToolButton")
    clickButton(":Skrooge operation plugin.Split_QToolButton")
    waitForObject(":Skrooge operation plugin.Transfer_QToolButton")
    clickButton(":Skrooge operation plugin.Transfer_QToolButton")
    waitForObject(":Skrooge operation plugin.Standard_QToolButton")
    clickButton(":Skrooge operation plugin.Standard_QToolButton")
    waitForObject(":Skrooge operation plugin.Clear form_KPushButton")
    clickButton(":Skrooge operation plugin.Clear form_KPushButton")
    waitForObject(":Skrooge operation plugin_KLineEdit")
    mouseClick(":Skrooge operation plugin_KLineEdit", 38, 15, 0, Qt.LeftButton)
    waitForObject(":Skrooge operation plugin_KLineEdit")
    type(":Skrooge operation plugin_KLineEdit", "<2>")
    waitForObject(":Skrooge operation plugin_KLineEdit")
    type(":Skrooge operation plugin_KLineEdit", "<0>")
    waitForObject(":Skrooge operation plugin_KLineEdit")
    type(":Skrooge operation plugin_KLineEdit", "<.>")
    waitForObject(":Skrooge operation plugin.Hide checked operations_QCheckBox")
    clickButton(":Skrooge operation plugin.Hide checked operations_QCheckBox")
    waitForObject(":Skrooge operation plugin.Hide checked operations_QCheckBox")
    clickButton(":Skrooge operation plugin.Hide checked operations_QCheckBox")
    waitForObject(":&Bookmark.kBookmarksList_SKGTreeView")
    openContextMenu(":&Bookmark.kBookmarksList_SKGTreeView", 118, 96, 2)
    waitForObject(":Untitled [modified] - skrooge_KMenu")
    type(":Untitled [modified] - skrooge_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge_KMenu")
    type(":Untitled [modified] - skrooge_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge_KMenu")
    type(":Untitled [modified] - skrooge_KMenu", "<Return>")
    waitForObject(":&Bookmark.kBookmarksList_SKGTreeView")
    openItemContextMenu(":&Bookmark.kBookmarksList_SKGTreeView", "Operations", 98, 14, 2)
    waitForObject(":Untitled [modified] - skrooge_KMenu")
    type(":Untitled [modified] - skrooge_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge_KMenu")
    type(":Untitled [modified] - skrooge_KMenu", "<Return>")
    waitForObject(":Untitled [modified] - skrooge_SKGMainPanel")
    sendEvent("QCloseEvent", ":Untitled [modified] - skrooge_SKGMainPanel")
    waitForObject(":Question – Skrooge.Do not save_KPushButton")
    clickButton(":Question – Skrooge.Do not save_KPushButton")

==> skrooge_0.7.2.2.orig.tar.gz: skrooge-0.7.2.2/tests/suite_squish/tst_create_operation/test.py <==
def main():
    source(findFile("scripts", "skrooge_functions.py"))
    initSimple()
    
    waitForObject(":Untitled - skrooge_KTabBar")
    type(":Untitled - skrooge_KTabBar", "<Ctrl+2>")
    waitForObject(":kAccountCreatorBank_KLineEdit")
    mouseClick(":kAccountCreatorBank_KLineEdit", 21, 15, 0, Qt.LeftButton)
    waitForObject(":kAccountCreatorBank_KLineEdit")
    type(":kAccountCreatorBank_KLineEdit", "A")
    waitForObject(":kAccountCreatorBank_KLineEdit")
    type(":kAccountCreatorBank_KLineEdit", "<Tab>")
    waitForObject(":kAccountCreatorAccount_KLineEdit_2")
    type(":kAccountCreatorAccount_KLineEdit_2", "A")
    clickButton(waitForObject(":Skrooge bank plugin.Add_KPushButton"))
    clickButton(waitForObject(":Skrooge bank plugin.Modify_KPushButton"))
    waitForObject(":kAccountCreatorAccount_KLineEdit_2")
    type(":kAccountCreatorAccount_KLineEdit_2", "<Ctrl+3>")
    waitForObject(":kAmountEdit_SKGCalculatorEdit_3")
    mouseClick(":kAmountEdit_SKGCalculatorEdit_3", 44, 8, 0, Qt.LeftButton)
    waitForObject(":kAmountEdit_SKGCalculatorEdit_3")
    type(":kAmountEdit_SKGCalculatorEdit_3", "<1>")
    waitForObject(":kAmountEdit_SKGCalculatorEdit_3")
    type(":kAmountEdit_SKGCalculatorEdit_3", "<0>")
    waitForObject(":kPayeeEdit_SKGComboBox")
    mouseClick(":kPayeeEdit_SKGComboBox", 62, 5, 0, Qt.LeftButton)
    waitForObject(":kPayeeEdit_SKGComboBox")
    type(":kPayeeEdit_SKGComboBox", "p")
    waitForObject(":kPayeeEdit_SKGComboBox")
    type(":kPayeeEdit_SKGComboBox", "<Tab>")
    waitForObject(":kTypeEdit_SKGComboBox")
    type(":kTypeEdit_SKGComboBox", "m")
    waitForObject(":kTypeEdit_SKGComboBox")
    type(":kTypeEdit_SKGComboBox", "<Tab>")
    waitForObject(":Skrooge operation plugin.kNumberEdit_SKGLineEdit")
    type(":Skrooge operation plugin.kNumberEdit_SKGLineEdit", "<Tab>")
    waitForObject(":kCategoryEdit_SKGComboBox_2")
    type(":kCategoryEdit_SKGComboBox_2", "c")
    waitForObject(":kCategoryEdit_SKGComboBox_2")
    type(":kCategoryEdit_SKGComboBox_2", "<Tab>")
    waitForObject(":kCategoryEdit_SKGComboBox_2")
    type(":kCategoryEdit_SKGComboBox_2", "<Tab>")
    waitForObject(":kCategoryEdit_SKGComboBox_2")
    type(":kCategoryEdit_SKGComboBox_2", "<Esc>")
    waitForObject(":kCategoryEdit_SKGComboBox_2")
    type(":kCategoryEdit_SKGComboBox_2", "<Tab>")
    waitForObject(":kCommentEdit_SKGComboBox")
    type(":kCommentEdit_SKGComboBox", "c")
    waitForObject(":kCommentEdit_SKGComboBox")
    type(":kCommentEdit_SKGComboBox", "<Tab>")
    waitForObject(":kTrackerEdit_SKGComboBox")
    type(":kTrackerEdit_SKGComboBox", "t")
    waitForObject(":kAmountEdit_SKGCalculatorEdit_3")
    mouseDrag(":kAmountEdit_SKGCalculatorEdit_3", 34, 10, 72, 0, 1, Qt.LeftButton)
    waitForObject(":kAmountEdit_SKGCalculatorEdit_3")
    type(":kAmountEdit_SKGCalculatorEdit_3", "<2>")
    waitForObject(":kAmountEdit_SKGCalculatorEdit_3")
    type(":kAmountEdit_SKGCalculatorEdit_3", "<0>")
    waitForObject(":kAmountEdit_SKGCalculatorEdit_3")
    clickButton(waitForObject(":Skrooge operation plugin.Add_KPushButton"))
    waitForObject(":kReconciliatorFrame.Templates_QToolButton")
    clickButton(":kReconciliatorFrame.Templates_QToolButton")
    waitForObject(":kReconciliatorFrame.Operations_QToolButton")
    clickButton(":kReconciliatorFrame.Operations_QToolButton")
    waitForObject(":kReconciliatorFrame.kReconciliatorButton_QToolButton")
    clickButton(":kReconciliatorFrame.kReconciliatorButton_QToolButton")
    waitForObject(":kReconciliatorFrame.kReconciliatorButton_QToolButton")
    clickButton(":kReconciliatorFrame.kReconciliatorButton_QToolButton")
    waitForObject(":Skrooge operation plugin.kOperationView_SKGTableView")
    mouseClick(":Skrooge operation plugin.kOperationView_SKGTableView", 1073, 556, 0, Qt.LeftButton)
    waitForObject(":Skrooge operation plugin.kOperationView_SKGTableView")
    type(":Skrooge operation plugin.kOperationView_SKGTableView", "<Ctrl+A>")
    waitForObject(":kReconciliatorFrame.kReconciliatorButton_QToolButton")
    clickButton(":kReconciliatorFrame.kReconciliatorButton_QToolButton")
    waitForObject(":Skrooge operation plugin.kOperationView_SKGTableView")
    mouseClick(":Skrooge operation plugin.kOperationView_SKGTableView", 228, 608, 0, Qt.LeftButton)
    waitForObject(":Skrooge operation plugin.Split_QToolButton")
    clickButton(":Skrooge operation plugin.Split_QToolButton")
    waitForObject(":Skrooge operation plugin.Transfer_QToolButton")
    clickButton(":Skrooge operation plugin.Transfer_QToolButton")
    waitForObject(":Skrooge operation plugin.Standard_QToolButton")
    clickButton(":Skrooge operation plugin.Standard_QToolButton")
    waitForObject(":Skrooge operation plugin.Clear form_KPushButton")
    clickButton(":Skrooge operation plugin.Clear form_KPushButton")
    waitForObject(":Skrooge operation plugin_KLineEdit")
    mouseClick(":Skrooge operation plugin_KLineEdit", 38, 15, 0, Qt.LeftButton)
    waitForObject(":Skrooge operation plugin_KLineEdit")
    type(":Skrooge operation plugin_KLineEdit", "<2>")
    waitForObject(":Skrooge operation plugin_KLineEdit")
    type(":Skrooge operation plugin_KLineEdit", "<0>")
    waitForObject(":Skrooge operation plugin_KLineEdit")
    type(":Skrooge operation plugin_KLineEdit", "<.>")
    waitForObject(":Skrooge operation plugin.Hide checked operations_QCheckBox")
    clickButton(":Skrooge operation plugin.Hide checked operations_QCheckBox")
    waitForObject(":Skrooge operation plugin.Hide checked operations_QCheckBox")
    clickButton(":Skrooge operation plugin.Hide checked operations_QCheckBox")
    waitForObject(":&Bookmark.kBookmarksList_SKGTreeView")
    openContextMenu(":&Bookmark.kBookmarksList_SKGTreeView", 118, 96, 2)
    waitForObject(":Untitled [modified] - skrooge_KMenu")
    type(":Untitled [modified] - skrooge_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge_KMenu")
    type(":Untitled [modified] - skrooge_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge_KMenu")
    type(":Untitled [modified] - skrooge_KMenu", "<Return>")
    waitForObject(":&Bookmark.kBookmarksList_SKGTreeView")
    openItemContextMenu(":&Bookmark.kBookmarksList_SKGTreeView", "Operations", 98, 14, 2)
    waitForObject(":Untitled [modified] - skrooge_KMenu")
    type(":Untitled [modified] - skrooge_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge_KMenu")
    type(":Untitled [modified] - skrooge_KMenu", "<Return>")
    waitForObject(":Untitled [modified] - skrooge_SKGMainPanel")
    sendEvent("QCloseEvent", ":Untitled [modified] - skrooge_SKGMainPanel")
    waitForObject(":Question – Skrooge.Do not save_KPushButton")
    clickButton(":Question – Skrooge.Do not save_KPushButton")
